Struct rand::distributions::gamma::FisherFUnstable
[-] [+]
[src]
pub struct FisherF {
// some fields omitted
}The Fisher F distribution F(m, n).
This distribution is equivalent to the ratio of two normalised
chi-squared distributions, that is, F(m,n) = (χ²(m)/m) / (χ²(n)/n).
Methods
impl FisherF
fn new(m: f64, n: f64) -> FisherF
Create a new FisherF distribution, with the given
parameter. Panics if either m or n are not positive.